﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  ACT距離計算サービス サンプルプログラム
'  CalcSettingsクラス
'
'  Copyrights (c) 2016-2023, Advanced Core Technologies, Inc. All rights reserved.
'
'  2023/09/21 Rev.1.0.0.1 KYON UseSsl変数をプロパティに変更
'  2016/02/12 Rev.1.0.0.0 MOTO 作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

Imports Act.Dcws

''' <summary>
''' 距離計算サービスに使用する設定を指定します。
''' </summary>
Friend Class CalcSettings

    '==============================================================================================
    '  Public Constants
    '==============================================================================================
#Region "Public Constants"

    ''' <summary>
    ''' 管理サービスURLの既定値です。
    ''' </summary>
    Public Shared ReadOnly DefaultAdminUrl As String =
        "https://distcalc.act-inc.co.jp/dcadmin/admin.asmx"

    ''' <summary>
    ''' 経緯度の測地系を指定します。
    ''' </summary>
    ''' <remarks>Tokyo（日本測地系）</remarks>
    Public Shared ReadOnly Datum As Datum = Datum.Tokyo

    ''' <summary>
    ''' 経緯度の座標フォーマット識別子を指定します。
    ''' </summary>
    ''' <remarks>現在は常に0を指定します</remarks>
    Public Shared ReadOnly CoordinateFormat As Integer = 0

    ''' <summary>
    ''' 住所検索用フラグを指定します。
    ''' </summary>
    ''' <remarks>None（なし）</remarks>
    Public Shared ReadOnly SearchFlag As SearchAddressFlag = Global.Act.Dcws.SearchAddressFlag.None

#End Region

    '==============================================================================================
    '  Public Property
    '==============================================================================================
#Region "Public Property"

    ''' <summary>
    ''' 通信プロトコルにSSLを使用するかどうかを指定します。
    ''' </summary>
    ''' <remarks>true（SSLを使用する）、false（SSLを使用しない）</remarks>
    Public Shared Property UseSsl As Boolean = False

#End Region

End Class
