﻿'//////////////////////////////////////////////////////////////////////////////////////////////////
' 
'  ACT距離計算サービス サンプルプログラム
'  ProgressDialogクラス
'
'  Copyrights (c) 2016 Advanced Core Technologies, Inc. All rights reserved.
'
'  2016/02/02 Rev.1.0.0.0 MOTO 作成
'
'//////////////////////////////////////////////////////////////////////////////////////////////////

Imports System.Threading.Tasks

''' <summary>
''' 非同期で処理を実行し、マーキースタイルのプログレスバーを表示します。
''' </summary>
Public Class ProgressDialog

    '==============================================================================================
    '  Constructors
    '==============================================================================================
#Region "Constructors"

    ''' <summary>
    ''' 表示するメッセージを指定して初期化します。
    ''' </summary>
    ''' <param name="message">表示するメッセージ</param>
    ''' <remarks></remarks>
    Private Sub New(ByVal message As String)
        InitializeComponent()
        labelMessage.Text = message
    End Sub

#End Region

    '==============================================================================================
    '  Private Fields
    '==============================================================================================
#Region "Private Fields"

    ''' <summary>
    ''' 実行中フラグです。
    ''' </summary>
    Private isRunning_ As Boolean

#End Region

    '==============================================================================================
    '  Public Methods
    '==============================================================================================
#Region "Public Methods"

    ''' <summary>
    ''' ダイアログをモーダルで表示し、指定した処理を非同期で実行します。
    ''' </summary>
    ''' <param name="action">実行する処理</param>
    ''' <param name="message">表示するメッセージ</param>
    Public Shared Sub Run(ByVal action As Action, ByVal message As String)
        Using dialog As New ProgressDialog(message)
            Dim uiContext = TaskScheduler.FromCurrentSynchronizationContext()
            Task.Factory.StartNew(Sub()
                                      dialog.isRunning_ = True
                                      action()
                                  End Sub) _
                        .ContinueWith(Sub(notUse As Object)
                                          dialog.isRunning_ = False
                                          dialog.Close()
                                      End Sub, uiContext)
            dialog.ShowDialog()
        End Using
    End Sub

#End Region

    '==============================================================================================
    '  Event Handlers
    '==============================================================================================
#Region "Event Handlers"

    ''' <summary>
    ''' フォームのクローズ中イベントです。
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub ProgressDialog_FormClosing(sender As Object, e As FormClosingEventArgs) Handles MyBase.FormClosing
        e.Cancel = isRunning_
    End Sub

#End Region
End Class